import { EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { MatMenuTrigger } from '@angular/material/menu';
import { CheckboxChange } from '@talenra/ngx-base/checkbox';
import { IAttributeItem } from '../../../shared/interfaces/attribute-item.interface';
import { IInteractedDataItems } from '../../../shared/interfaces/interacted-data-items.interface';
import { DataItemsClass } from '../../../shared/classes/dataItem.class';
import { IPairingAttributes } from '../../../shared/interfaces/pairing-attributes.interface';
import { DataItemsService } from '../data-items.service';
import { InboxState } from '../../../inbox/state/inbox.state';
import { InboxToolbarService } from '../../../inbox-toolbar/inbox-toolbar.service';
import * as i0 from "@angular/core";
/**
 * The subcategory of the data item list. Here a single pair of data is considered.  When selecting an element, various
 * actions are possible, e.g. displaying further information.
 *
 * ```html
 * <talenra-data-item
 *   [dataItem]="item"
 *   [furtherActionsMenu]="furtherActionsMenu"
 *   (dataItemsInteractions)="onDataItemsInteractions($event)"
 *   (clickedDataItem)="onSelectClick(item)"
 *   (shiftDataItem)="onShiftDataItemClick(item)"
 * ></talenra-data-item>
 * ```
 */
export declare class DataItemComponent implements OnInit, OnDestroy, OnChanges {
    /**
     * Input attribute for the data item which is displayed in the UI.
     */
    dataItem: any;
    /**
     * Input for the selected data item.
     */
    selectedDataItem: any;
    /**
     * Input for the selected main attributes
     */
    selectedMainAttributes: IAttributeItem[];
    /**
     * Input for pairing attributes
     */
    pairingAttributes: IPairingAttributes[];
    /**
     * Input attribute to disable the icon buttons.
     */
    disableButtons: boolean;
    /**
     * Input attribute for the checkbox value.
     */
    checkboxValueChange: boolean;
    /**
     * Input attribute to check if the data item is locked.
     */
    lockedDataItem: boolean;
    /**
     * Transfer the clicked data item from the data items list item to the data item sidebar information.
     */
    clickedDataItem: EventEmitter<any>;
    /**
     * Transfer the clicked data item from the data items list item to the data item sidebar information.
     */
    shiftDataItem: EventEmitter<any>;
    /**
     * EventEmitter to send data items interactions.
     */
    dataItemsInteractions: EventEmitter<IInteractedDataItems>;
    /**
     * EventEmitter to send checkbox interactions.
     */
    checkBoxInteraction: EventEmitter<{
        checkedValue: boolean;
        dataItem: any;
    }>;
    /**
     * Child of the toolbar mat-menu.
     */
    talenraInboxDataItemsListItemMenuTrigger: MatMenuTrigger;
    /**
     * Formgroup for the checkbox.
     */
    checkedForm: FormGroup;
    /**
     * Class to interact with data-item
     */
    dataItemsClass: DataItemsClass;
    /**
     * The number of displayed attributes.
     */
    numberShownAttributes: number;
    /**
     * The changed main attributes. Changed to incorporate the pairing of attributes.
     */
    changedMainAttributes: IAttributeItem[];
    /**
     * The changed main attributes. The first half of the changed main attributes.
     */
    firstChangedMainAttributes: IAttributeItem[];
    /**
     * The changed main attributes. The second half of the changed main attributes.
     */
    secondChangedMainAttributes: IAttributeItem[];
    /**
     * The inbox service.
     */
    inboxState: InboxState;
    /**
     * The data items service.
     */
    dataItemsService: DataItemsService;
    /**
     * The inbox toolbar service.
     */
    inboxToolbarService: InboxToolbarService;
    /**
     * The Math object to use for calculations.
     * @protected
     */
    protected readonly Math: Math;
    /**
     * The subscriptions of the data item list component.
     * @internal
     */
    private subscriptions;
    /**
     * The observable for the resize event.
     * @private
     */
    private resizeObservable$;
    /**
     * The subscription for the resize event.
     * @private
     */
    private resizeSubscription$;
    /**
     * The changeDetectorRef reference.
     * @private
     */
    private changeDetectorRef;
    /**
     * The keyboard service.
     * @private
     */
    private keyboardService;
    /**
     * Initializes the data item list component.
     * @internal
     */
    ngOnInit(): void;
    /**
     * Detects changes in the input values.
     * @param changes The changes.
     * @internal
     **/
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Unsubscribes from all subscriptions.
     * @internal
     */
    ngOnDestroy(): void;
    /**
     * To transfer data item list to data item sidebar information.
     */
    onDataItemListItemTransferClick(): void;
    /**
     * After the checkbox is clicked, mouseEvent is propagated to stop further propagation on the whole item click.
     * @param {MouseEvent} event MouseEvent on the checkbox click.
     */
    onCheckboxClick(event: MouseEvent): void;
    /**
     * After the icon is clicked, action possibilities will be shown.
     * IconBtnFunction in inbox component handles the process.
     * @param source The source of the click.
     */
    onGetActionsClick(source?: string): void;
    /**
     * After the icon is clicked, the new process step (open new page, etc.) will start.
     * IconBtnFunction in inbox component handles the process.
     * @param {MouseEvent} event MouseEvent on the icon click.
     */
    onStartProcessClick(event: MouseEvent): void;
    /**
     * Handles the changes of the checkbox.
     * @param event
     */
    onCheckedChange(event: CheckboxChange): void;
    /**
     * The subscription, which handles the action menu interaction (open/close).
     * @param value The value given by the subscription.
     */
    interactionActionMenuSubscription(value: boolean): void;
    /**
     * Handles the closing of the action menu.
     * Sets the value for the public api.
     */
    onActionsMenuClosed(): void;
    /**
     * Initializes the component.
     * @internal
     */
    private initializeComponent;
    /**
     * Resets the component on changes
     * @private
     */
    private resetOnChange;
    /**
     * Handles the pairing of specific attributes.
     * @private
     */
    private attributePairingHandler;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataItemComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DataItemComponent, "talenra-data-item", never, { "dataItem": { "alias": "dataItem"; "required": false; }; "selectedDataItem": { "alias": "selectedDataItem"; "required": false; }; "selectedMainAttributes": { "alias": "selectedMainAttributes"; "required": false; }; "pairingAttributes": { "alias": "pairingAttributes"; "required": false; }; "disableButtons": { "alias": "disableButtons"; "required": false; }; "checkboxValueChange": { "alias": "checkboxValueChange"; "required": false; }; "lockedDataItem": { "alias": "lockedDataItem"; "required": false; }; }, { "clickedDataItem": "clickedDataItem"; "shiftDataItem": "shiftDataItem"; "dataItemsInteractions": "dataItemsInteractions"; "checkBoxInteraction": "checkBoxInteraction"; }, never, ["[further-actions-menu]"], true, never>;
}
