import { EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { MatMenuTrigger } from '@angular/material/menu';
import { MenuLinkComponent } from '@talenra/ngx-base/menu';
import { MatSnackBar } from '@angular/material/snack-bar';
import { InboxToolbarService } from './inbox-toolbar.service';
import { CheckboxState } from '../shared/types/checkbox.types';
import { KeyboardService } from '../inbox/services/keyboard.service';
import { InboxDetailViewService } from '../inbox-layout/inbox-detail-view/inbox-detail-view.service';
import { DataItemsService } from '../inbox-layout/data-items-list/data-items.service';
import { InboxState } from '../inbox/state/inbox.state';
import { ChangedPresetValuesService } from '../inbox/services/changed-preset-values.service';
import { FilterToolbarService } from '../filter-toolbar/filter-toolbar.service';
import { FilterStateService } from '../simple-filter-selection/state/filter.state';
import { UpdatePresetsService } from '../inbox/services/update-presets.service';
import * as i0 from "@angular/core";
/**
 * The toolbar is an important component that allows to access needed data from the data items list faster and increase
 * the usability.
 *
 * ```html
 * <talenra-inbox-toolbar
 *   [disabledButtons]="disabledButtons"
 *   [checkedForm]="checkedForm"
 *   (iconBtn)="iconBtnFunction($event)"
 * ></talenra-inbox-toolbar>
 * ```
 */
export declare class InboxToolbarComponent implements OnInit, OnChanges, OnDestroy {
    /**
     * Input to disable checkbox behavior and UI.
     */
    disableBulkInteractionButtons: boolean;
    /**
     * Input to disable the detail view tab change button in the toolbar and set it to a fixed state.
     * Used to set state if no data items are found.
     */
    fixDisableDetailViewToggle: boolean;
    /**
     * Number of marked data items.
     */
    numberMarkedDataItems: number;
    /**
     * Boolean to show if the data is to be refreshed.
     */
    refreshing: boolean;
    /**
     * Checkbox state of the toolbar checkbox.
     */
    checkboxState: CheckboxState;
    /**
     * EventEmitter for icon button clicks.
     */
    iconBtn: EventEmitter<string>;
    /**
     * EventEmitter to delete preset.
     */
    deletePreset: EventEmitter<[string, string]>;
    /**
     * EventEmitter to change preset name
     */
    changePresetName: EventEmitter<[string, string, string]>;
    /**
     * Emitter for the change in the checkbox state of the toolbar checkbox.
     */
    checkboxStateChange: EventEmitter<CheckboxState>;
    /**
     * EventEmitter for the interactions with the preset.
     */
    presetInteractions: import("@angular/core").OutputEmitterRef<string>;
    /**
     * Emitter to reset the preset to the default preset.
     */
    resetPreset: import("@angular/core").OutputEmitterRef<void>;
    /**
     * Child of the toolbar mat-menu.
     */
    talenraInboxToolbarMenuTrigger: MatMenuTrigger | undefined;
    /**
     * Form for checkbox interaction.
     */
    checkedForm: FormGroup;
    /**
     * List style for the checkbox behavior and UI.
     */
    checkboxIndeterminate: boolean;
    /**
     * Width of the toolbar.
     * Used to show compressed or toolbar buttons into menu.
     */
    toolbarWidth: import("@angular/core").WritableSignal<number>;
    /**
     * The width of the line break setting.
     */
    LINEBREAKWIDTH: number;
    /**
     * The inbox service.
     */
    inboxState: InboxState;
    /**
     * The inbox service.
     */
    filterState: FilterStateService;
    /**
     * The inbox detail view service.
     */
    inboxDetailViewService: InboxDetailViewService;
    /**
     * The data items service.
     */
    dataItemsService: DataItemsService;
    /**
     * The inbox toolbar service.
     */
    inboxToolbarService: InboxToolbarService;
    /**
     * The preset change service.
     */
    changedPresetValuesService: ChangedPresetValuesService;
    /**
     * The update preset service.
     * @internal
     */
    updatePresetsService: UpdatePresetsService;
    /**
     * The filter toolbar service.
     */
    filterToolbarService: FilterToolbarService;
    /**
     * The snackbar service.
     * @internal
     * @TODO: replace with opus injectors as soon as they are available
     */
    _snackBar: MatSnackBar;
    /**
     * The keyboard service.
     * @internal
     * @private
     */
    keyboardService: KeyboardService;
    /**
     * Injected service for confirmation.
     */
    private overlayService;
    /**
     * Semaphore to stop accessing checkbox value a second time.
     * @internal
     */
    private checkboxSemaphore;
    /**
     * The subscriptions of the inbox toolbar component.
     * @internal
     * @private
     */
    private subscriptions;
    /**
     * The observable for the resize event.
     * @internal
     * @private
     */
    private resizeObservable$;
    /**
     * The subscription to the resize observable.
     * @internal
     * @private
     */
    private resizeSubscription$;
    /**
     * The element reference.
     * @internal
     * @private
     */
    private elementRef;
    /**
     * The zone.
     * @internal
     * @private
     */
    private zone;
    /**
     * Initializes the subscriptions of the resize observable.
     * @internal
     */
    private observer;
    /**
     * The confirmation model for the preset save and overwrite.
     */
    private presetConfirmationConfig;
    /**
     * Initializes the inbox toolbar component.
     * @internal
     */
    ngOnInit(): void;
    /**
     * Called when the component input is changed.
     * @internal
     * @param changes The changes of the component.
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Unsubscribes and unobserved from all subscriptions.
     * @internal
     */
    ngOnDestroy(): void;
    /**
     * Click event emit that attribute settings side panel will open.
     * @param {MouseEvent} event Click event.
     * @param {string} tab The tab to open.
     */
    openConfigurationPanel(event: MouseEvent, tab: string): void;
    /**
     * Click event emit that inbox detail view side panel will close.
     * @param {MouseEvent} event Click event.
     */
    onDetailsClick(event: MouseEvent): void;
    /**
     * Click event emit that 'unfold-less' and 'unfold-more' icon will switch.
     * @param {MouseEvent} event Click event.
     */
    onCompressClick(event: MouseEvent): void;
    /**
     * Click event emit that a CSV can be downloaded.
     * @param {MouseEvent} event Click event.
     */
    onDownloadClick(event: MouseEvent): void;
    /**
     * Click event emit that more actions can be seen.
     * @param {string} source The source of the click event.
     */
    onGetActionsClick(source?: string): void;
    /**
     * Click event emit that the process can start.
     */
    onStartProcessClick(): void;
    /**
     * Click event emit that the refresh btn is clicked.
     */
    onRefreshClick(): void;
    /**
     * Handles the closing of the action menu.
     * Sets the value for the public api.
     */
    onActionsMenuClosed(): void;
    /**
     * Function to reset the preset to the default preset.
     */
    resetPresetToDefault(): void;
    /**
     * Handles the opening of the action menu if accessed by a subscription.
     * @param value The value of the subscription.
     */
    interactionActionMenuSubscriptions(value: boolean): void;
    /**
     * Handles the click event of the condensed toolbar menu.
     * @param toolbarAction The menu component which is clicked.
     */
    condensedToolbarMenu: (toolbarAction: MenuLinkComponent) => void;
    /**
     * Changes the checkbox state in the form.
     * @param value The value of the checkbox state.
     * @private
     */
    private changeCheckboxState;
    /**
     * Delete all icon filters.
     */
    private deleteIconFilters;
    /**
     * Open the preset save/overwrite dialog.
     */
    openPresetSaveDialog(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<InboxToolbarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<InboxToolbarComponent, "talenra-inbox-toolbar", never, { "disableBulkInteractionButtons": { "alias": "disableBulkInteractionButtons"; "required": false; }; "fixDisableDetailViewToggle": { "alias": "fixDisableDetailViewToggle"; "required": false; }; "numberMarkedDataItems": { "alias": "numberMarkedDataItems"; "required": false; }; "refreshing": { "alias": "refreshing"; "required": false; }; "checkboxState": { "alias": "checkboxState"; "required": false; }; }, { "iconBtn": "iconBtn"; "deletePreset": "deletePreset"; "changePresetName": "changePresetName"; "checkboxStateChange": "checkboxStateChange"; "presetInteractions": "presetInteractions"; "resetPreset": "resetPreset"; }, never, ["[custom-toolbar-space]", "[further-actions-menu]"], true, never>;
}
