import { BehaviorSubject } from 'rxjs';
import { IAttributeItem } from '../../shared/interfaces/attribute-item.interface';
import { IPreset } from '../../shared/interfaces/preset.interface';
import { IInboxConfiguration } from '../../shared/interfaces/inbox-configuration.interface';
import { IFilterSortSearch } from '../../shared/interfaces/filter-search-sort.interface';
import * as i0 from "@angular/core";
/**
 * Provides control and state of the publicly available subjects of the inbox state.
 *
 * ## Import Information:
 *
 * 1. Not all attributes are changeable. Or should be changed (consult the api documentation).
 *
 * ```typescript
 * import { InboxState } from '@talenra/ngx-inbox';
 * ```
 */
export declare class InboxState {
    /**
     * Provides the inbox configuration.
     */
    readonly inboxConfiguration$: BehaviorSubject<IInboxConfiguration>;
    /**
     * Provides whether the action menu (mat-menu) is expanded or not.
     * @Usage data items and inbox toolbar
     */
    readonly actionMenuExpanded$: BehaviorSubject<boolean>;
    /**
     * The actions menu click flag.
     * This flag is used to prevent an infinite loop of the actions menu opening, when the inbox is setting it to true.
     * @internal
     */
    readonly actionsMenuClickFlag: BehaviorSubject<boolean>;
    /**
     * Provides the selected main attributes.
     */
    readonly selectedMainAttributesSubject$: BehaviorSubject<IAttributeItem[]>;
    /**
     * Provides the selected detail attributes.
     */
    readonly selectedDetailAttributesSubject$: BehaviorSubject<IAttributeItem[]>;
    /**
     * Provides  all selected attributes.
     */
    readonly selectedAllAttributesSubject$: BehaviorSubject<IAttributeItem[]>;
    /**
     * Provides the active preset.
     */
    readonly activePreset$: BehaviorSubject<IPreset>;
    /**
     * Data items which are filtered and sorted.
     */
    readonly filteredDataItemsSubject$: BehaviorSubject<any[]>;
    /**
     * All preSetOptionsGroups which are available.
     * @internal
     */
    readonly presetGroups$: BehaviorSubject<IPreset[]>;
    /**
     * The preset name of the active view.
     * @internal
     */
    readonly activePresetName$: BehaviorSubject<string[]>;
    /**
     * The selected tab.
     * @internal
     */
    selectedSidePanelTab: import("@angular/core").WritableSignal<string>;
    /**
     * The active filters, sort and search information.
     */
    readonly activeFilterSortSearch: BehaviorSubject<IFilterSortSearch>;
    /**
     * Updates the inbox configuration.
     *
     * @param configuration The new inbox configuration.
     */
    setInboxConfiguration(configuration: IInboxConfiguration): void;
    /**
     * Collapses or expands the side-navigation
     *
     * @param isExpanded Whether the action-menu is expanded or not.
     */
    setActionMenuExpanded(isExpanded: boolean): void;
    /**
     * Sets the actions menu click flag.
     * @param value The value to set.
     * @internal
     */
    setActionsMenuClickFlag(value: boolean): void;
    /**
     * Sets the selected main attributes for the filter toolbar.
     * @param selectedMainAttributes The selected main attributes.
     * @internal
     */
    setSelectedMainAttributesSubject(selectedMainAttributes: IAttributeItem[]): void;
    /**
     * Sets the selected detail attributes for the filter toolbar.
     * @param selectedDetailAttributes The selected detail attributes.
     * @internal
     */
    setSelectedDetailAttributesSubject(selectedDetailAttributes: IAttributeItem[]): void;
    /**
     * Sets the selected all attributes for the filter toolbar.
     * @param selectedAllAttributes The selected all attributes.
     * @internal
     */
    setSelectedAllAttributesSubject(selectedAllAttributes: IAttributeItem[]): void;
    /**
     * Sets the active view for the filter toolbar.
     * @param activeView The active view.
     * @internal
     */
    setActivePreset(activeView: IPreset): void;
    /**
     * Sets the filtered data items.
     * @param filteredDataItems The filtered data items.
     * @internal
     */
    setFilteredDataItemsSubject(filteredDataItems: any[]): void;
    /**
     * Sets the preSetOptionsGroups.
     * @param key The preSetOptionsGroups.
     * @internal
     */
    setPresetGroups(key: IPreset[]): void;
    /**
     * Sets the active view name.
     * @param key The active view name.
     * @internal
     */
    setActivePresetName(key: string[]): void;
    /**
     * Sets the active filter sort search.
     * @param key The active filter sort search.
     * @internal
     */
    setActiveFilterSortSearch(key: IFilterSortSearch): void;
    /**
     * Sets the selected side panel tab.
     * @param tab The selected side panel tab.
     */
    setSelectedSidePanelTab(tab: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<InboxState, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<InboxState>;
}
