import { OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { MatSnackBar } from '@angular/material/snack-bar';
import { BehaviorSubject } from 'rxjs';
import { CdkDragDrop } from '@angular/cdk/drag-drop';
import { PresetsService } from './presets.service';
import { KeyboardService } from '../inbox/services/keyboard.service';
import { FilterToolbarService } from '../filter-toolbar/filter-toolbar.service';
import { UpdatePresetsService } from '../inbox/services/update-presets.service';
import { InboxState } from '../inbox/state/inbox.state';
import { IPreset } from '../shared/interfaces/preset.interface';
import { TInboxAccordionActions } from '../input-components/inbox-accordion/accordion/accordion.component';
import * as i0 from "@angular/core";
export declare class PresetsComponent implements OnInit, OnChanges {
    /**
     * The incoming presetGroups to find with the activePresetName the necessary preset.
     */
    presetGroups: import("@angular/core").InputSignal<IPreset[]>;
    /**
     * EventEmitter for the interactions with the preset.
     */
    presetInteractions: import("@angular/core").OutputEmitterRef<string>;
    /**
     * The index of the preset that is currently edited corresponding with the order in the presetGroups.
     */
    indexOfPresetInEditing: number;
    /**
     * The index of the group that is currently edited corresponding with the order in the presetGroups.
     */
    indexOfPresetGroupInEditing: number;
    /**
     * Name of the active preset.
     */
    activePresetName: string[];
    /**
     * In many scenarios, the delete button int the preset menu should be hidden.
     * This map stores the information if the delete button should be shown or not.
     */
    showDeleteButton: Map<string, boolean>;
    /**
     * Value if the drag and drop is disabled, if the preset is edited through name change and deletion process.
     */
    dragAndDropDisabled: boolean;
    /**
     * BehaviorSubject for edit state if a preset is currently edited and the other should not be interactable.
     */
    editState: BehaviorSubject<boolean>;
    /**
     * This array will store the extracted values from the presetGroups.
     */
    originalPresetGroupNames: {
        groupName: string;
        presetNames: string[];
    }[];
    /**
     * The filter toolbar service.
     * @internal
     */
    filterToolbarService: FilterToolbarService;
    /**
     * The preset service.
     * @internal
     */
    presetsService: PresetsService;
    /**
     * The keyboard service.
     * @internal
     */
    keyboardService: KeyboardService;
    /**
     * The update preset service.
     * @internal
     */
    updatePresetsService: UpdatePresetsService;
    /**
     * The state service.
     * @internal
     */
    inboxState: InboxState;
    /**
     * The snackbar service.
     * @internal
     * @TODO: replace with talenra injectors as soon as they are available
     */
    _snackBar: MatSnackBar;
    /**
     * Information about the visibility of the presets.
     * The first value is the name of the group, the second value is the name of the preset and the third value is the visibility of the preset.
     * @private
     */
    private visibilityOfPresets;
    /**
     * The subscriptions of the inbox toolbar component.
     * @internal
     * @private
     */
    private subscriptions;
    /**
     * Initializes the inbox toolbar component.
     * @internal
     */
    ngOnInit(): void;
    /**
     * Handles the changes of the presetGroups.
     * @param changes The changes of the presetGroups.
     * @internal
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * To change the array place of dragged item.
     * @param event The dragged item.
     * @internal
     */
    drop(event: CdkDragDrop<string>): void;
    /**
     * Presets are readonly by default. Only if the preset is edited, the preset is editable.
     * @param groupIndex The index of the group.
     * @param presetIndex The index of the preset.
     * @param event The mouse event.
     */
    setTextAreaAsEditable(groupIndex: number, presetIndex: number, event: Event): void;
    /**
     * To change the name of a preset and make only one preset editable.
     * @param groupName The name of the group.
     * @param oldPresetName The old name of the preset.
     * @param newPresetName The new name of the preset.
     */
    renamingPreset(groupName: string, oldPresetName: string, newPresetName: string): void;
    /**
     * To change the array place of presets.
     * @param groupName The name of the group.
     * @param preset The preset that will be moved.
     * @param direction The direction of the movement.
     */
    updatePresetPosition(groupName: string, preset: IPreset, direction: 'up' | 'down'): void;
    /**
     * Delete presets and emit it to the presets.
     * @param groupName The name of the group that contains the preset.
     * @param presetName The name of the preset that will be deleted.
     * @param event The mouse event.
     */
    deletePreset(groupName: string, presetName: string, event: MouseEvent): void;
    /**
     * Check and save the visibility of the preset.
     * @param bool The visibility of the preset.
     * @param groupName The name of the group.
     * @param presetName The name of the preset.
     */
    changePresetVisibility(bool: boolean, groupName: string, presetName: string): void;
    /**
     * A button to confirm to delete of a preset is shown.
     * @param bool Determines if the button is shown or not.
     * @param groupName The name of the group.
     * @param presetName The name of the preset.
     * @param event The mouse event.
     */
    accessDeletePreset(bool: boolean, groupName: string, presetName: string, event: MouseEvent): void;
    /**
     * Handling the change in the edit state if clicked on all elements except the text area.
     * @param event The mouse event.
     * @param nextState The next state of the edit state.
     */
    changeEditState(event: MouseEvent, nextState: boolean): void;
    /**
     * Handling of a click on the text area of a preset name.
     * Stops propagation if the preset is currently edited.
     * @param event The mouse event.
     * @param presetIndex The index of the preset.
     * @param groupIndex The index of the group.
     */
    clickTextAreaName(event: MouseEvent, presetIndex: number, groupIndex: number): void;
    /**
     * Handling the enter press during the renaming of a preset.
     *
     * @param event The keyboard event.
     * @param group The group of the presets.
     * @param optionName The name of the preset.
     * @param inputText The text of the input.
     */
    checkAndRenamePreset(event: Event, group: string, optionName: string, inputText: string): void;
    /**
     * Update the textarea value if the preset is currently edited.
     * @param groupIndex The index of the group.
     */
    private updateTextareaValue;
    /**
     * Initializes the component.
     * @private
     */
    private initializeComponent;
    /**
     * Returns the disabled and hidden actions for the group.
     * @param groupIndex The index of the group.
     */
    getDisabledHiddenActions(groupIndex: number): TInboxAccordionActions[];
    /**
     * Handles the accordion action.
     * @param action The accordion action.
     * @param group The group.
     */
    onAccordionAction(action: TInboxAccordionActions, group: IPreset): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<PresetsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PresetsComponent, "talenra-presets", never, { "presetGroups": { "alias": "presetGroups"; "required": true; "isSignal": true; }; }, { "presetInteractions": "presetInteractions"; }, never, never, true, never>;
}
