/**
 * IIconInput is used to define the icon filter for an attribute.
 *
 * @example
 * // Import
 * import { IIconInput } from '@talenra/ngx-inbox';
 *
 * const iconInput: IIconInput = {
 *       identifier: 'caseFlags',
 *       icon: 'error',
 *       activeIconColor: 'primary',
 *       iconTooltip: 'Hinweis',
 *       displayedString: (elem) => {
 *         return 'Beinhaltet die Rolle MA' + elem['caseFlags'].filter((s: string | string[]) => s.includes('MA')).length;
 *       },
 *       assignmentCondition: (elem) => {
 *         return elem['caseFlags'].filter((s: string | string[]) => s.includes('MA')).length != 0;
 *       },
 *     },
 *
 */
export interface IIconInput {
    /**
     * The identifier of the icon filter (has to correspond with the key of the attribute).
     */
    identifier: string;
    /**
     * The icon is limited by the talenra-icon library (https://gitlab.svanet.ch/talenra/talenra-workspace).
     */
    icon: string;
    /**
     * The color of the icon if it is active.
     */
    activeIconColor: 'status-red' | 'status-green' | 'status-orange' | 'status-violet' | 'primary' | 'black';
    /**
     * Tooltip for the icon displayed in the filter toolbar.
     */
    iconTooltip: string;
    /**
     * The displayedString is used to define the property, which is displayed in the note box.
     * @param args Is the data item which is inputted in the inbox `dataItems`.
     */
    displayedString: (args: any) => string;
    /**
     * The assignmentCondition is used to define the condition for the icon filter (which data item gets the icon note).
     * @param args Is the data item which is inputted in the inbox `dataItems`.
     */
    assignmentCondition: (args: any) => boolean;
    /**
     * Flag if the icon is chosen as active in the icon filter.
     */
    active?: boolean;
}
