import { TemplateRef } from '@angular/core';
import { BehaviorSubject } from 'rxjs';
/**
 * Interface to input the dynamic content and settings for the detail view tabs.
 *
 * ```typescript
 * import { IInboxTabBarItem } from '@talenra/ngx-inbox';
 *
 * @ViewChild('talenraInboxDocuments', { read: TemplateRef }) talenraInboxDocuments!: TemplateRef<any>;
 * @ViewChild('talenraInboxComments', { read: TemplateRef }) talenraInboxComments!: TemplateRef<any>;
 * @ViewChild('talenraInboxHistory', { read: TemplateRef }) talenraInboxHistory!: TemplateRef<any>;
 *
 * specificInboxTabBarItems: IInboxTabBarItem[] = [
 *   {
 *     label: 'documents',
 *     icon: 'description',
 *     counter: new BehaviorSubject<number>(8),
 *     useScroll: false,
 *     detailViewTabContentTemplate: this.talenraInboxDocuments,
 *   },
 *   {
 *     label: 'comments',
 *     icon: 'chat-bubble-outline',
 *     counter: new BehaviorSubject<number>(100),
 *     maxCounter: 50,
 *     useScroll: true,
 *     detailViewTabContentTemplate: this.talenraInboxComments,
 *   },
 *   {
 *     label: 'history',
 *     icon: 'history',
 *     useScroll: false,
 *     detailViewTabContentTemplate: this.talenraInboxHistory,
 *   },
 * ];
 * ```
 */
export interface IInboxTabBarItem {
    /**
     * Unique key used to identify the item.
     */
    key?: string;
    /**
     * Label of the tab.
     */
    label: string;
    /**
     * The icon is limited by the talenra-icon library (https://gitlab.svanet.ch/talenra/talenra-workspace).
     */
    icon: string;
    /**
     * Counter of the tab. Can be changed by the consuming application during runtime.
     */
    counter?: BehaviorSubject<number>;
    /**
     * Maximum value of the counter. If the counter exceeds this value, it will be displayed as 'maxCounter+'.
     * Default is 99.
     */
    maxCounter?: number;
    /**
     * If true, the tab content will be wrapped in a scrollable container.
     */
    useScroll: boolean;
    /**
     * TemplateRef of the tab content.
     */
    detailViewTabContentTemplate?: TemplateRef<any>;
}
