import { OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { FormControl, FormGroup } from '@angular/forms';
import { validateDate } from '@talenra/ngx-base/date';
import { ISelectedFilterAttribute } from '../../shared/interfaces/selected-filter-attribute.interface';
import * as i0 from "@angular/core";
/**
 * Range filter component, which enables three possible filter types:
 * 1. date-range
 * 2. char-range
 * 3. number-range
 * All three filter types are used to filter the data items by a range of values.
 * The filter displays two input fields, one for the start value and one for the end value.
 * An error message for the start and end input field is displayed if the input is syntactically false.
 *
 * ```html
 * <talenra-range-filter (filterSelection)="onFilterSelection($event)" [attribute]="selectedAttribute"></talenra-range-filter>
 * ```
 */
export declare class RangeFilterComponent implements OnInit, OnChanges, OnDestroy {
    /**
     * The attribute to identify which filter is selected.
     */
    attribute: import("@angular/core").InputSignal<ISelectedFilterAttribute>;
    /**
     * The filterSelection output is used to emit the filter values.
     */
    filterSelection: import("@angular/core").OutputEmitterRef<ISelectedFilterAttribute>;
    /**
     * The char and number range values.
     */
    charNumberRange: FormGroup<{
        start: FormControl<string | number | null | undefined>;
        end: FormControl<string | number | null | undefined>;
    }>;
    /**
     *  The date range values.
     */
    dateRange: FormGroup;
    /**
     * The falseEndInput is used to check if the end input is syntactically false.
     */
    falseEndInput: boolean;
    /**
     * The charRangeAlphabet is the alphabet that is used for the char range filter.
     * @internal
     */
    private readonly charRangeAlphabet;
    /**
     * Destroy references to subscriptions.
     */
    private destroyRef;
    /**
     * The filter state service is used to set the filter and sort subject.
     */
    private filterStateService;
    /**
     * The filter state service is used to set the filter and sort subject.
     */
    private inboxToolbarService;
    /**
     * The unique id of the range filter. Needed for the false order range filter.
     */
    private id;
    protected readonly dateInTheFutureFilter: (allowToday: boolean) => import("@talenra/ngx-base/date").DateFilterFn;
    protected readonly validateDate: typeof validateDate;
    protected readonly dateInThePastFilter: (allowToday: boolean) => import("@talenra/ngx-base/date").DateFilterFn;
    /**
     * This method is called when the component is initialized.
     * @internal
     */
    ngOnInit(): void;
    /**
     * @internal
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * @internal
     */
    ngOnDestroy(): void;
    /**
     * Resets the chosen filter values.
     * @param mouseEvent The mouse event.
     */
    resetFilterAttribute(mouseEvent: MouseEvent): void;
    /**
     * Auxiliary method to check if start string is before the end string of the given alphabet.
     * @param start The start string.
     * @param end The end string.
     */
    checkEndInputFalse(start: string | number, end: string | number): void;
    /**
     * Function is necessary to prevent the enter key from being pressed.
     * @param event The event if the enter key is pressed.
     */
    onEnterKey(event: Event): void;
    /**
     * Sorts the string values.
     * Returns -1 if a is smaller than b.
     * @param a String to compare.
     * @param b String to compare.
     * @internal
     */
    sortString(a: string, b: string): 1 | -1;
    /**
     * All selected filters will be saved in the map with there defintion and values
     * @param filterIdentifier The filterIdentifier is the name that is used to identify the filter.
     * @param start The start value of the filter.
     * @param end The end value of the filter.
     */
    private onValuesSelected;
    /**
     * Function is necessary to reset the values of the filter.
     */
    private resetValues;
    /**
     * Function is necessary to initialize the filter values.
     */
    private initializeFilterValues;
    /**
     * Replaces specific char in a string at a specific index.
     * @param str String to replace char in.
     * @param index Index where to replace in str.
     * @param replacement Replacement char.
     * @internal
     */
    private replaceCharAt;
    static ɵfac: i0.ɵɵFactoryDeclaration<RangeFilterComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<RangeFilterComponent, "talenra-range-filter", never, { "attribute": { "alias": "attribute"; "required": true; "isSignal": true; }; }, { "filterSelection": "filterSelection"; }, never, never, true, never>;
}
